package com.wyattjmiller.dicerollerapp

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.Button
import android.widget.TextView
import kotlin.random.Random
import kotlin.random.nextInt

class DiceActivity : AppCompatActivity() {

    // Private member variables per the layout
    private lateinit var mMetaStatusTextView: TextView
    private lateinit var mDiceTextView: TextView
    private lateinit var mRollButton: Button

    // Private member variable - other
    private lateinit var mDieStatus: Die

    // The following methods are for keeping track of the Android lifecycle using Logcat
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_dice)

        mMetaStatusTextView = findViewById(R.id.metaStatusTextView)
        mDiceTextView = findViewById(R.id.diceTextView)
        mRollButton = findViewById(R.id.rollButton)

        // I realize that you toggle visibility in xml
        mDiceTextView.visibility = View.INVISIBLE
    }

    override fun onStart() {
        Log.d("LIFECYCLE", "onStart invoked!")
        super.onStart()
    }

    override fun onResume() {
        Log.d("LIFECYCLE", "onResume invoked!")
        super.onResume()
    }

    override fun onPause() {
        Log.d("LIFECYCLE", "onPause invoked!")
        super.onPause()
    }

    override fun onStop() {
        Log.d("LIFECYCLE", "onStop invoked!")
        super.onStop()
    }

    override fun onDestroy() {
        Log.d("LIFECYCLE", "onDestroy invoked!")
        super.onDestroy()
    }

    // code behind for the 'roll d4' button
    fun onClickDieFourRoll(view: View?) {
        val item: Array<FourDie> = FourDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = FourDie.One
            1 -> mDieStatus = FourDie.Two
            2 -> mDieStatus = FourDie.Three
            3 -> mDieStatus = FourDie.Four
        }

        mMetaStatusTextView.text = "You have rolled a D4!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }


    // code behind for the 'roll' button
    fun onClickDieRoll(view: View?) {
        val item: Array<SixDie> = SixDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = SixDie.One
            1 -> mDieStatus = SixDie.Two
            2 -> mDieStatus = SixDie.Three
            3 -> mDieStatus = SixDie.Four
            4 -> mDieStatus = SixDie.Five
            5 -> mDieStatus = SixDie.Six
        }

        mMetaStatusTextView.text = "You have rolled a D6!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }

    // code behind for the 'roll d8' button
    fun onClickDieEightRoll(view: View?) {
        val item: Array<EightDie> = EightDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = EightDie.One
            1 -> mDieStatus = EightDie.Two
            2 -> mDieStatus = EightDie.Three
            3 -> mDieStatus = EightDie.Four
            4 -> mDieStatus = EightDie.Five
            5 -> mDieStatus = EightDie.Six
            6 -> mDieStatus = EightDie.Seven
            7 -> mDieStatus = EightDie.Eight
        }

        mMetaStatusTextView.text = "You have rolled a D8!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }

    // code behind for the 'roll d10' button
    fun onClickDieTenRoll(view: View?) {
        val item: Array<TenDie> = TenDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = TenDie.One
            1 -> mDieStatus = TenDie.Two
            2 -> mDieStatus = TenDie.Three
            3 -> mDieStatus = TenDie.Four
            4 -> mDieStatus = TenDie.Five
            5 -> mDieStatus = TenDie.Six
            6 -> mDieStatus = TenDie.Seven
            7 -> mDieStatus = TenDie.Eight
            8 -> mDieStatus = TenDie.Nine
            9 -> mDieStatus = TenDie.Ten
        }

        mMetaStatusTextView.text = "You have rolled a D10!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }

    // code behind the 'roll d12' button
    fun onClickDieTwelveRoll(view: View?) {
        val item: Array<TwelveDie> = TwelveDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = TwelveDie.One
            1 -> mDieStatus = TwelveDie.Two
            2 -> mDieStatus = TwelveDie.Three
            3 -> mDieStatus = TwelveDie.Four
            4 -> mDieStatus = TwelveDie.Five
            5 -> mDieStatus = TwelveDie.Six
            6 -> mDieStatus = TwelveDie.Seven
            7 -> mDieStatus = TwelveDie.Eight
            8 -> mDieStatus = TwelveDie.Nine
            9 -> mDieStatus = TwelveDie.Ten
            10 -> mDieStatus = TwelveDie.Eleven
            11 -> mDieStatus = TwelveDie.Twelve
        }

        mMetaStatusTextView.text = "You have rolled a D12!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }


    // code behind the 'roll d20' button
    fun onClickDieTwentyRoll(view: View?) {
        val item: Array<TwentyDie> = TwentyDie.values()
        when (Randomizer().randomDieRoll(item)) {
            0 -> mDieStatus = TwentyDie.One
            1 -> mDieStatus = TwentyDie.Two
            2 -> mDieStatus = TwentyDie.Three
            3 -> mDieStatus = TwentyDie.Four
            4 -> mDieStatus = TwentyDie.Five
            5 -> mDieStatus = TwentyDie.Six
            6 -> mDieStatus = TwentyDie.Seven
            7 -> mDieStatus = TwentyDie.Eight
            8 -> mDieStatus = TwentyDie.Nine
            9 -> mDieStatus = TwentyDie.Ten
            10 -> mDieStatus = TwentyDie.Eleven
            11 -> mDieStatus = TwentyDie.Twelve
            12 -> mDieStatus = TwentyDie.Thirteen
            13 -> mDieStatus = TwentyDie.Fourteen
            14 -> mDieStatus = TwentyDie.Fifteen
            15 -> mDieStatus = TwentyDie.Sixteen
            16 -> mDieStatus = TwentyDie.Seventeen
            17 -> mDieStatus = TwentyDie.Eighteen
            18 -> mDieStatus = TwentyDie.Nineteen
            19 -> mDieStatus = TwentyDie.Twenty
        }

        mMetaStatusTextView.text = "You have rolled a D20!"
        mDiceTextView.text = mDieStatus.toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }

    // code behind the 'roll d100' button
    // I'm not going to make an enum that's a hundred lines long lol
    fun onClickDie100Roll(view: View?) {
        mMetaStatusTextView.text = "You have rolled a D100!"
        mDiceTextView.text = Random.nextInt(0..100).toString()

        if (mDiceTextView.visibility == View.INVISIBLE) {
            mDiceTextView.visibility = View.VISIBLE
        }
    }
}